=============================================
The Earth Science Box Modeling Toolkit ESBMTK
=============================================


The Earth Science Box Modeling Toolkit (ESBMTK) is a python library that  provides a an object oriented approach to development of Harvardton-Bear type models. The ESBMTK classes allow to describe models in a declarative way where the model definition serves also as the model documentation. 

ESBMTK provides abstractions for a variety of processes, e.g., gas-exchange across the air-sea interface, or marine carbonate chemistry and isotope calculations. It's modular nature allows to easily extend or change existing models.

Originally envisioned as a teaching tool, it is currently being used in several research projects. The library is under constant development, but the basic API is stable.


Contents
========

.. toctree::
   :maxdepth: 2

   Introduction <manual/manual>
   Implementing more complex models <manual/manual-2>
   Seawater & Carbon Chemisrty <manual/manual-3>
   Extending ESBMTK <manual/manual-4>
   Contributions & Help <contributing>
   Authors <authors>
   Changelog <changelog>
   Module Reference <api/modules>
   License <license>


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. _toctree: https://www.sphinx-doc.org/en/master/usage/restructuredtext/directives.html
.. _reStructuredText: https://www.sphinx-doc.org/en/master/usage/restructuredtext/basics.html
.. _references: https://www.sphinx-doc.org/en/stable/markup/inline.html
.. _Python domain syntax: https://www.sphinx-doc.org/en/master/usage/restructuredtext/domains.html#the-python-domain
.. _Sphinx: https://www.sphinx-doc.org/
.. _Python: https://docs.python.org/
.. _Numpy: https://numpy.org/doc/stable
.. _SciPy: https://docs.scipy.org/doc/scipy/reference/
.. _matplotlib: https://matplotlib.org/contents.html#
.. _Pandas: https://pandas.pydata.org/pandas-docs/stable
.. _Scikit-Learn: https://scikit-learn.org/stable
.. _autodoc: https://www.sphinx-doc.org/en/master/ext/autodoc.html
.. _Google style: https://google.github.io/styleguide/pyguide.html#38-comments-and-docstrings
.. _NumPy style: https://numpydoc.readthedocs.io/en/latest/format.html
.. _classical style: https://www.sphinx-doc.org/en/master/domains.html#info-field-lists
